Module analytics

Module analytics 

Analytics collection and reporting. Analytics and monitoring for RBAC systems.

This module provides comprehensive analytics capabilities for monitoring and analyzing RBAC usage patterns, security compliance, and system performance.

Status: Analytics are event-backed today. The compliance, reports, metrics, and dashboard modules derive results from stored analytics events and persisted snapshots, and they expand as additional collectors feed the pipeline.

Modules

compliance
RBAC Compliance Monitoring
dashboard
RBAC Analytics Dashboard
metrics
RBAC Metrics Collection and Processing
reports
RBAC Analytics Reports

Structs

AnalyticsConfig
Analytics configuration
AnalyticsEvent
Analytics event data
AnalyticsManager
Main analytics manager
AnalyticsReport
Comprehensive analytics report
ComplianceMetrics
Security compliance metrics
PerformanceMetrics
Performance metrics for RBAC operations
PermissionUsageStats
Permission usage analytics
ResourceAccess
Resource access statistics
RoleUsageStats
Role usage statistics
TimeRange
Time range for analytics queries
TimeSeriesData
Time-based analytics data
TrendAnalysis
Analytics trend information
UserActivity
User activity statistics

Enums

AnalyticsError
Analytics-related errors
EventResult
Event result types
RbacEventType
RBAC analytics event types
ReportType
Report types
TrendDirection
Trend direction