Module metrics

Module metrics 

RBAC Metrics Collection and Processing

This module provides metrics collection, aggregation, and analysis for RBAC system performance and usage patterns.

Status: Event persistence is wired up today, and higher-level metrics currently reflect the analytics events collected so far.

Structs

MetricsCollector
Metrics collector
MetricsConfig
Metrics collector configuration