pub struct BackupCodeVerifyRequest {
pub backup_code: String,
}Expand description
POST /mfa/verify-backup-code — authenticate with a one-time backup code.
Verifies a backup code for the authenticated user and consumes it (one-time use). This can be used in lieu of a TOTP code when the user has lost access to their authenticator app.
Fields
backup_code: StringThe plaintext backup code to verify.