pub struct MaintenanceOperations<'a> { /* private fields */ }Expand description
Focused maintenance operations exposed via AuthFramework::maintenance().
Backup, restore, and reset authentication state in the configured storage
backend. All operations support an ExecutionMode parameter that
controls whether changes are applied or merely previewed.
Example
let maint = auth.maintenance();
// Preview a backup without writing to disk
let preview = maint.backup("/tmp/auth_backup.json", ExecutionMode::DryRun).await?;
println!("Would export {} records", preview.manifest.user_count);
// Perform the real backup
let report = maint.backup("/tmp/auth_backup.json", ExecutionMode::Execute).await?;Implementations
Sourceimpl MaintenanceOperations<'_>
impl MaintenanceOperations<'_>
Sourcepub async fn backup(
&self,
output_path: &str,
mode: ExecutionMode,
) -> Result<BackupReport>
pub async fn backup( &self, output_path: &str, mode: ExecutionMode, ) -> Result<BackupReport>
Export a logical snapshot to disk.
Uses ExecutionMode for clarity at call sites.
Sourcepub async fn backup_to_file(
&self,
output_path: &str,
dry_run: bool,
) -> Result<BackupReport>
pub async fn backup_to_file( &self, output_path: &str, dry_run: bool, ) -> Result<BackupReport>
Export a logical snapshot to disk (legacy API).
Prefer backup with an ExecutionMode for
self-documenting call sites.
Sourcepub async fn restore(
&self,
backup_path: &str,
mode: ExecutionMode,
) -> Result<RestoreReport>
pub async fn restore( &self, backup_path: &str, mode: ExecutionMode, ) -> Result<RestoreReport>
Restore a logical snapshot from disk.
Uses ExecutionMode for clarity at call sites.
Sourcepub async fn restore_from_file(
&self,
backup_path: &str,
dry_run: bool,
) -> Result<RestoreReport>
pub async fn restore_from_file( &self, backup_path: &str, dry_run: bool, ) -> Result<RestoreReport>
Restore a logical snapshot from disk (legacy API).
Prefer restore with an ExecutionMode for
self-documenting call sites.
Sourcepub async fn reset_with_mode(&self, mode: ExecutionMode) -> Result<ResetReport>
pub async fn reset_with_mode(&self, mode: ExecutionMode) -> Result<ResetReport>
Reset logical authentication state in the configured backend.
Uses ExecutionMode for clarity at call sites.
Sourcepub async fn reset(&self, dry_run: bool) -> Result<ResetReport>
pub async fn reset(&self, dry_run: bool) -> Result<ResetReport>
Reset logical authentication state in the configured backend (legacy API).
Prefer reset_with_mode with an
ExecutionMode for self-documenting call sites.