Module service

Module service 

Enhanced Authorization Service using role-system v1.0

This service provides a unified interface for all authorization operations, replacing the fragmented authorization systems in AuthFramework.

Structs

AuthorizationConfig
Configuration for the authorization service
AuthorizationService
Enhanced authorization service providing enterprise-grade RBAC