pub enum MfaError {
ChallengeExpired,
InvalidCode,
MethodNotSupported {
method: String,
},
SetupRequired,
VerificationFailed {
message: String,
},
}Expand description
Multi-factor authentication errors.
Variants
ChallengeExpired
The MFA challenge window has elapsed; the user must request a new challenge.
InvalidCode
The TOTP or one-time code provided by the user is incorrect.
MethodNotSupported
The requested MFA method (e.g. SMS, hardware key) is not enabled.
SetupRequired
MFA has not been configured for this account yet.
VerificationFailed
MFA verification failed for a reason described in message.
Implementations
Sourceimpl MfaError
impl MfaError
Sourcepub fn method_not_supported(method: impl Into<String>) -> Self
pub fn method_not_supported(method: impl Into<String>) -> Self
Create a new method not supported error.
Example
use auth_framework::errors::MfaError;
let err = MfaError::method_not_supported("biometric");
assert!(err.to_string().contains("biometric"));Sourcepub fn verification_failed(message: impl Into<String>) -> Self
pub fn verification_failed(message: impl Into<String>) -> Self
Create a new verification failed error.
Example
use auth_framework::errors::MfaError;
let err = MfaError::verification_failed("code expired");
assert!(err.to_string().contains("code expired"));Trait Implementations
Sourceimpl Error for MfaError
impl Error for MfaError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()