pub struct GnapTransactionRequestBuilder { /* private fields */ }Expand description
Builder for GnapTransactionRequest.
Implementations
Sourceimpl GnapTransactionRequestBuilder
impl GnapTransactionRequestBuilder
Sourcepub fn client(self, client: GnapClientInfo) -> Self
pub fn client(self, client: GnapClientInfo) -> Self
Set the client info with a key binding.
Sourcepub fn client_key(self, jwk: GnapJwk, proof: impl Into<String>) -> Self
pub fn client_key(self, jwk: GnapJwk, proof: impl Into<String>) -> Self
Set client info from a key and proof method.
Sourcepub fn redirect_interaction(
self,
callback_uri: impl Into<String>,
nonce: impl Into<String>,
) -> Self
pub fn redirect_interaction( self, callback_uri: impl Into<String>, nonce: impl Into<String>, ) -> Self
Set interaction requirements for redirect flow.
Sourcepub fn interact(self, interact: GnapInteractionRequirements) -> Self
pub fn interact(self, interact: GnapInteractionRequirements) -> Self
Set interaction requirements (raw).
Sourcepub fn access(
self,
access_type: impl Into<String>,
actions: &[impl AsRef<str>],
locations: &[impl AsRef<str>],
) -> Self
pub fn access( self, access_type: impl Into<String>, actions: &[impl AsRef<str>], locations: &[impl AsRef<str>], ) -> Self
Add an access request with type, actions, and locations.
Sourcepub fn access_type(self, access_type: impl Into<String>) -> Self
pub fn access_type(self, access_type: impl Into<String>) -> Self
Add a simple access request (type only, no actions/locations).
Sourcepub fn subject_formats(self, formats: Vec<String>) -> Self
pub fn subject_formats(self, formats: Vec<String>) -> Self
Request subject information with the given identifier formats.
Sourcepub fn subject(self, subject: GnapSubjectRequest) -> Self
pub fn subject(self, subject: GnapSubjectRequest) -> Self
Request subject information (raw).
Sourcepub fn build(self) -> GnapTransactionRequest
pub fn build(self) -> GnapTransactionRequest
Build the GnapTransactionRequest.