pub struct HotpManager { /* private fields */ }Expand description
HOTP manager for generating and validating counter-based OTPs.
Implementations
Sourceimpl HotpManager
impl HotpManager
Sourcepub fn new(config: HotpConfig) -> Self
pub fn new(config: HotpConfig) -> Self
Create a new HOTP manager with the given configuration.
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create a new HOTP manager with default configuration.
Sourcepub fn generate_secret() -> Result<String>
pub fn generate_secret() -> Result<String>
Generate a cryptographically random 20-byte secret encoded as RFC 4648 Base32 (with padding).
Sourcepub fn generate(&self, secret_b32: &str, counter: u64) -> Result<String>
pub fn generate(&self, secret_b32: &str, counter: u64) -> Result<String>
Generate an HOTP code for the given secret and counter value.
Implements RFC 4226 5.3 — Dynamic Truncation.
Sourcepub fn validate(
&self,
secret_b32: &str,
counter: u64,
code: &str,
) -> Result<Option<u64>>
pub fn validate( &self, secret_b32: &str, counter: u64, code: &str, ) -> Result<Option<u64>>
Validate an HOTP code against the expected counter value.
On success, returns the counter value that matched (which may be
ahead of counter by up to look_ahead_window). The caller should
persist matched_counter + 1 as the new expected counter.