pub struct KerberosManager { /* private fields */ }Expand description
Kerberos / SPNEGO authentication manager.
Implementations
Sourceimpl KerberosManager
impl KerberosManager
Sourcepub fn new(config: KerberosConfig) -> Result<Self>
pub fn new(config: KerberosConfig) -> Result<Self>
Create a new Kerberos manager.
Sourcepub async fn load_keytab(&self, path: &str) -> Result<usize>
pub async fn load_keytab(&self, path: &str) -> Result<usize>
Load keytab entries from file.
Sourcepub async fn authenticate(
&self,
negotiate_token: &str,
) -> Result<KerberosAuthResult>
pub async fn authenticate( &self, negotiate_token: &str, ) -> Result<KerberosAuthResult>
Process an HTTP Authorization: Negotiate <token> header.
Returns the authentication result on success, or an appropriate error.
The caller should return the response_token (if any) in a
WWW-Authenticate: Negotiate <token> response header.
Sourcepub fn generate_challenge(&self) -> String
pub fn generate_challenge(&self) -> String
Generate a WWW-Authenticate: Negotiate challenge header value.
Sourcepub async fn check_replay(&self, token_data: &[u8]) -> Result<()>
pub async fn check_replay(&self, token_data: &[u8]) -> Result<()>
Check for replay attacks using a raw token hash (for backwards compat).