Module siwe

Module siwe 

Sign-In with Ethereum (SIWE / ERC-4361) support.

Provides message construction, parsing, and validation for the ERC-4361 standard which allows Ethereum account holders to authenticate with off-chain services by signing a structured message.

References

Structs

SiweMessage
A SIWE message conforming to ERC-4361.

Functions

parse_siwe_message
Parse a SIWE plaintext message string back into a SiweMessage.
verify_siwe_message
Verify the SIWE message fields are valid (time constraints, nonce, etc.).