pub struct WsSecurityConfigBuilder { /* private fields */ }Expand description
A builder for WsSecurityConfig.
Obtain via WsSecurityConfig::builder().
Implementations
Sourceimpl WsSecurityConfigBuilder
impl WsSecurityConfigBuilder
Sourcepub fn include_timestamp(self, include: bool) -> Self
pub fn include_timestamp(self, include: bool) -> Self
Set whether to include a timestamp in the security header.
Sourcepub fn timestamp_ttl(self, ttl: Duration) -> Self
pub fn timestamp_ttl(self, ttl: Duration) -> Self
Set the timestamp TTL (time-to-live).
Sourcepub fn sign_message(self, sign: bool) -> Self
pub fn sign_message(self, sign: bool) -> Self
Set whether to sign the message.
Sourcepub fn elements_to_sign(self, elements: Vec<String>) -> Self
pub fn elements_to_sign(self, elements: Vec<String>) -> Self
Set which XML elements to sign (by local name).
Sourcepub fn signing_certificate(self, cert: Vec<u8>) -> Self
pub fn signing_certificate(self, cert: Vec<u8>) -> Self
Set the signing certificate (PEM-encoded bytes).
Sourcepub fn signing_private_key(self, key: Vec<u8>) -> Self
pub fn signing_private_key(self, key: Vec<u8>) -> Self
Set the signing private key (PEM-encoded bytes).
Sourcepub fn include_certificate(self, include: bool) -> Self
pub fn include_certificate(self, include: bool) -> Self
Set whether to include the certificate in the security header.
Sourcepub fn saml_token_endpoint(self, endpoint: impl Into<String>) -> Self
pub fn saml_token_endpoint(self, endpoint: impl Into<String>) -> Self
Set the SAML token provider endpoint URL.
Sourcepub fn actor(self, actor: impl Into<String>) -> Self
pub fn actor(self, actor: impl Into<String>) -> Self
Set the actor value for delegation scenarios.
Sourcepub fn build(self) -> WsSecurityConfig
pub fn build(self) -> WsSecurityConfig
Build the WsSecurityConfig.