pub struct TupleToUserset {
pub tupleset_relation: String,
pub computed_userset_relation: String,
}Expand description
A tuple-to-userset rewrite rule.
Fields
tupleset_relation: StringThe relation to traverse on the current object (e.g. “parent”).
computed_userset_relation: StringThe relation to check on the resolved object (e.g. “viewer”).