pub async fn presentation_request() -> Json<Value>Expand description
OpenID4VP (Verifiable Presentations) request endpoint.
Serves presentation requests directing clients to submit matching claims.
Example
use auth_framework::api::advanced_protocols::presentation_request;
// Provides the Presentation Definition specifying exactly which claims
// the user needs to share with the relying party.